@@ -22,7 +22,7 @@ from calculate.lib.utils.files import process, FilesError, readFile
 from calculate.lib.utils.common import (
     getValueFromCmdLine, getVideoFromXorgLog, getVideoFromXorgConf,
     getVideoFromCmdLine, getCompositeFromXorgconf, getTupleVersion,
-    getVideoFromModules, getVideoFromVendor, getInstalledVideo)
+    getVideoFromModules, getVideoFromVendor, getInstalledVideo, CmdlineParams)
 from calculate.lib.utils.portage import isPkgInstalled
 from math import sqrt
 
@@ -91,7 +91,8 @@ class VariableOsX11Resolution(Variable):
 
         # get resolution from command line
         reRightResolution = re.compile("^(\d+x\d+|auto)$", re.S)
-        kernelResolution = getValueFromCmdLine("calculate", 3)
+        kernelResolution = getValueFromCmdLine(
+            CmdlineParams.Calculate, CmdlineParams.Resolution)
         if kernelResolution and reRightResolution.match(kernelResolution):
             return {'auto': ''}.get(kernelResolution, kernelResolution)
         else:
@@ -186,4 +187,4 @@ class VariableOsX11VideoDrv(ReadonlyVariable):
             drv = func(*args)
             if drv in list_video:
                 return drv
-        return "other"
+        return "default"
